# pysdtw

Torch implementation of the Soft-DTW algorithm, supports both cpu and gpu
hardware.

This repository started as a fork from this [repo](https://github.com/Maghoumi/pytorch-softdtw-cuda).
The main source is included in the tests repository.
